==> estateplat-common-1.2.4-20210421.062911-727-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhYgxx.java <==
package cn.gtmap.estateplat.model.exchange.share;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangpeng2@gtmap.cn">zhangpeng2</a>
 * @version 1.0, 2019/5/26
 * @description 银行预告信息
 */
@Table(name = "gx_yh_ygxx")
public class GxYhYgxx implements Serializable {
    @Id
    private String ywid;//主键业务id
    private String qlid;//权利id
    private String zl;//坐落
    private String fwlx;//房屋类型
    private String bdclx;//不动产类型
    private String ghyt;//规划用途
    private String fwxz;//房屋性质
    private Integer szc;//所在层
    private Integer zcs;//总层数
    private Double dzwmj;//定着物面积
    private String dzwyt;//定着物用途
    private Double jzmj;//建筑面积
    private Double fttdmj;//分摊土地面积
    private String bdcdyh;//不动产单元号
    private String fwjg;//房屋结构
    private Double dytdmj;//独用土地面积
    private Date ksrq;//开始日期
    private Date jsrq;//结束日期
    private Double zdzhmj;//宗地宗海面积
    private String zdzhyt;//宗地宗海用途
    private String zdzhqlxz;//宗地宗海权利性质
    private String gyfs;//共有方式
    private String djyy;//登记原因
    private String djzx;//登记子项
    private String sfhcdzzz;//是否合成电子证照
    private String dbfw;//担保范围

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getDzwmj() {
        return dzwmj;
    }

    public void setDzwmj(Double dzwmj) {
        this.dzwmj = dzwmj;
    }

    public String getDzwyt() {
        return dzwyt;
    }

    public void setDzwyt(String dzwyt) {
        this.dzwyt = dzwyt;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Date getKsrq() {
        return ksrq;
    }

    public void setKsrq(Date ksrq) {
        this.ksrq = ksrq;
    }

    public Date getJsrq() {
        return jsrq;
    }

    public void setJsrq(Date jsrq) {
        this.jsrq = jsrq;
    }

    public Double getZdzhmj() {
        return zdzhmj;
    }

    public void setZdzhmj(Double zdzhmj) {
        this.zdzhmj = zdzhmj;
    }

    public String getZdzhyt() {
        return zdzhyt;
    }

    public void setZdzhyt(String zdzhyt) {
        this.zdzhyt = zdzhyt;
    }

    public String getZdzhqlxz() {
        return zdzhqlxz;
    }

    public void setZdzhqlxz(String zdzhqlxz) {
        this.zdzhqlxz = zdzhqlxz;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }
}

==> estateplat-common-1.2.4-20210622.094623-796-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhYgxx.java <==
package cn.gtmap.estateplat.model.exchange.share;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangpeng2@gtmap.cn">zhangpeng2</a>
 * @version 1.0, 2019/5/26
 * @description 银行预告信息
 */
@Table(name = "gx_yh_ygxx")
public class GxYhYgxx implements Serializable {
    @Id
    private String ywid;//主键业务id
    private String qlid;//权利id
    private String zl;//坐落
    private String fwlx;//房屋类型
    private String bdclx;//不动产类型
    private String ghyt;//规划用途
    private String fwxz;//房屋性质
    private Integer szc;//所在层
    private Integer zcs;//总层数
    private Double dzwmj;//定着物面积
    private String dzwyt;//定着物用途
    private Double jzmj;//建筑面积
    private Double fttdmj;//分摊土地面积
    private String bdcdyh;//不动产单元号
    private String fwjg;//房屋结构
    private Double dytdmj;//独用土地面积
    private Date ksrq;//开始日期
    private Date jsrq;//结束日期
    private Double zdzhmj;//宗地宗海面积
    private String zdzhyt;//宗地宗海用途
    private String zdzhqlxz;//宗地宗海权利性质
    private String gyfs;//共有方式
    private String djyy;//登记原因
    private String djzx;//登记子项
    private String sfhcdzzz;//是否合成电子证照
    private String dbfw;//担保范围
    private Double zgzqe;//最高债权额
    private String sfxzzr;//是否限制转让 是或否

    public String getDbfw() {
        return dbfw;
    }

    public void setDbfw(String dbfw) {
        this.dbfw = dbfw;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public Integer getSzc() {
        return szc;
    }

    public void setSzc(Integer szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getDzwmj() {
        return dzwmj;
    }

    public void setDzwmj(Double dzwmj) {
        this.dzwmj = dzwmj;
    }

    public String getDzwyt() {
        return dzwyt;
    }

    public void setDzwyt(String dzwyt) {
        this.dzwyt = dzwyt;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Date getKsrq() {
        return ksrq;
    }

    public void setKsrq(Date ksrq) {
        this.ksrq = ksrq;
    }

    public Date getJsrq() {
        return jsrq;
    }

    public void setJsrq(Date jsrq) {
        this.jsrq = jsrq;
    }

    public Double getZdzhmj() {
        return zdzhmj;
    }

    public void setZdzhmj(Double zdzhmj) {
        this.zdzhmj = zdzhmj;
    }

    public String getZdzhyt() {
        return zdzhyt;
    }

    public void setZdzhyt(String zdzhyt) {
        this.zdzhyt = zdzhyt;
    }

    public String getZdzhqlxz() {
        return zdzhqlxz;
    }

    public void setZdzhqlxz(String zdzhqlxz) {
        this.zdzhqlxz = zdzhqlxz;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getSfhcdzzz() {
        return sfhcdzzz;
    }

    public void setSfhcdzzz(String sfhcdzzz) {
        this.sfhcdzzz = sfhcdzzz;
    }

    public Double getZgzqe() {
        return zgzqe;
    }

    public void setZgzqe(Double zgzqe) {
        this.zgzqe = zgzqe;
    }

    public String getSfxzzr() {
        return sfxzzr;
    }

    public void setSfxzzr(String sfxzzr) {
        this.sfxzzr = sfxzzr;
    }
}
